.. _apps-tasks:

=============================
Distributed Task Queues
=============================

.. automodule:: pulsar.apps.tasks


API
===============

Taskqueue
~~~~~~~~~~~~~

.. autoclass:: TaskQueue
   :members:
   :member-order: bysource

Job
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: Job
   :members:
   :member-order: bysource

Periodic Job
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: PeriodicJob
   :members:
   :member-order: bysource

Task
~~~~~~~~

.. autoclass:: Task
   :members:
   :member-order: bysource


TaskQueue Rpc Mixin
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: TaskQueueRpcMixin
   :members:
   :member-order: bysource

Scheduler
~~~~~~~~~~~~~

.. autoclass:: Scheduler
   :members:
   :member-order: bysource

TaskConsumer
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: TaskConsumer
   :members:
   :member-order: bysource

Job Registry
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: JobRegistry
   :members:
   :member-order: bysource

Job meta Class
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: JobMetaClass
   :members:
   :member-order: bysource

